==> vue-quarter-panel-2.22.1.tgz: package/lib/index.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/quarter-panel/vue';
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import YearTable from '@opentinyvue/vue-year-table';
import { iconDoubleRight, iconDoubleLeft } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/quarter-panel/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "QuarterPanel",
  components: {
    YearTable,
    IconDoubleRight: iconDoubleRight(),
    IconDoubleLeft: iconDoubleLeft()
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "name": "tiny-zoom-in-top"
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.visible,
      expression: "state.visible"
    }],
    staticClass: "tiny-quarter-panel tiny-picker-panel tiny-date-picker"
  }, [_c("div", {
    staticClass: "tiny-quarter-panel__header"
  }, [_c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-date-picker__prev-btn tiny-icon-d-arrow-left",
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.cusPrevYear
    }
  }, [_c("icon-double-left")], 1), _c("span", {
    staticClass: "tiny-date-picker__header-label",
    attrs: {
      "role": "button"
    },
    on: {
      "click": _vm.showYearPicker
    }
  }, [_vm._v(_vm._s(_vm.state.yearLabel))]), _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-date-picker__next-btn tiny-icon-d-arrow-right",
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.cusNextYear
    }
  }, [_c("icon-double-right")], 1)]), _c("div", {
    staticClass: "tiny-quarter-panel__content tiny-picker-panel__content"
  }, [_vm.state.currentView === "quarter" ? _c("table", {
    staticClass: "tiny-quarter-panel__table",
    on: {
      "click": _vm.handleQuarterTableClick
    }
  }, [_c("tbody", [_c("tr", _vm._l(_vm.state.rows, function(row, key) {
    return _c("td", {
      key,
      class: _vm.getCellStyle(row)
    }, [_c("div", [_c("a", {
      staticClass: "cell",
      domProps: {
        "textContent": _vm._s(row.text)
      }
    })])]);
  }), 0)])]) : _vm._e(), _vm.state.currentView === "year" ? _c("year-table", {
    ref: "yearTable",
    attrs: {
      "value": _vm.state.value,
      "default-value": _vm.state.defaultValue ? new Date(_vm.state.defaultValue) : null,
      "date": _vm.state.date,
      "disabled-date": _vm.state.disabledDate,
      "selection-mode": _vm.state.selectionMode,
      "start-year": _vm.state.startYear
    },
    on: {
      "pick": _vm.handleYearPick
    }
  }) : _vm._e()], 1)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var QuerterPanel = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.undefined";
QuerterPanel.install = function(Vue) {
  Vue.component(QuerterPanel.name, QuerterPanel);
};
QuerterPanel.version = version;

export { QuerterPanel as default };

==> vue-quarter-panel-2.23.0.tgz: package/lib/index.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/quarter-panel/vue';
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import YearTable from '@opentinyvue/vue-year-table';
import { iconDoubleRight, iconDoubleLeft } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/quarter-panel/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "QuarterPanel",
  components: {
    YearTable,
    IconDoubleRight: iconDoubleRight(),
    IconDoubleLeft: iconDoubleLeft()
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "name": "tiny-zoom-in-top"
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.visible,
      expression: "state.visible"
    }],
    staticClass: "tiny-quarter-panel tiny-picker-panel tiny-date-picker"
  }, [_c("div", {
    staticClass: "tiny-quarter-panel__header"
  }, [_c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-date-picker__prev-btn tiny-icon-d-arrow-left",
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.cusPrevYear
    }
  }, [_c("icon-double-left")], 1), _c("span", {
    staticClass: "tiny-date-picker__header-label",
    attrs: {
      "role": "button"
    },
    on: {
      "click": _vm.showYearPicker
    }
  }, [_vm._v(_vm._s(_vm.state.yearLabel))]), _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-date-picker__next-btn tiny-icon-d-arrow-right",
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.cusNextYear
    }
  }, [_c("icon-double-right")], 1)]), _c("div", {
    staticClass: "tiny-quarter-panel__content tiny-picker-panel__content"
  }, [_vm.state.currentView === "quarter" ? _c("table", {
    staticClass: "tiny-quarter-panel__table",
    on: {
      "click": _vm.handleQuarterTableClick
    }
  }, [_c("tbody", [_c("tr", _vm._l(_vm.state.rows, function(row, key) {
    return _c("td", {
      key,
      class: _vm.getCellStyle(row)
    }, [_c("div", [_c("a", {
      staticClass: "cell",
      domProps: {
        "textContent": _vm._s(row.text)
      }
    })])]);
  }), 0)])]) : _vm._e(), _vm.state.currentView === "year" ? _c("year-table", {
    ref: "yearTable",
    attrs: {
      "value": _vm.state.value,
      "default-value": _vm.state.defaultValue ? new Date(_vm.state.defaultValue) : null,
      "date": _vm.state.date,
      "disabled-date": _vm.state.disabledDate,
      "selection-mode": _vm.state.selectionMode,
      "start-year": _vm.state.startYear
    },
    on: {
      "pick": _vm.handleYearPick
    }
  }) : _vm._e()], 1)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var QuerterPanel = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.23.0";
QuerterPanel.install = function(Vue) {
  Vue.component(QuerterPanel.name, QuerterPanel);
};
QuerterPanel.version = version;

export { QuerterPanel as default };
